@@ -18,7 +18,7 @@ class BaseSpider(object):
     def __init__(self, task_name, redis_config=None, mysql_config=None, mail_config=None, log_level=logging.DEBUG, log_file_path=None):
         self.use_proxy_request = False  # 是否使用代理
         self.task_name = task_name.lower()
-        self.logger = get_logger(task_name, log_level=log_level, log_file_path=log_file_path)
+        self.logger = get_logger(name=task_name, log_path=log_file_path, log_level=log_level)
 
         if redis_config:
             # 连接redis
