@@ -9,6 +9,7 @@ import string
 import datetime
 import zipfile
 import psutil
+from selenium.webdriver.common.by import By
 from dddd_utils.basespider import BaseSpider
 
 
@@ -162,7 +163,7 @@ class SeleniumBaseSpider(BaseSpider):
         cookies = ""
         for cookie in cookie_dict:
             if not cookie["name"].startswith("_"):
-                cookies += cookie["name"] + "=" + cookie["value"]
+                cookies += cookie["name"] + "=" + cookie["value"] + ";"
         return cookies
 
     def __create_proxyauth_extension(self, proxy_host, proxy_port, proxy_username, proxy_password, scheme="http"):
@@ -266,17 +267,17 @@ class SeleniumBaseSpider(BaseSpider):
         element = None
         by = by.lower()
         if by == "id":
-            element = browser.find_element_by_id(value)
+            element = browser.find_element(by=By.ID, value=value)
         elif by == "name":
-            element = browser.find_element_by_name(value)
+            element = browser.find_element(by=By.NAME, value=value)
         elif by == "xpath":
-            element = browser.find_element_by_xpath(value)
+            element = browser.find_element(by=By.XPATH, value=value)
         elif by == "classname":
-            element = browser.find_element_by_class_name(value)
+            element = browser.find_element(by=By.CLASS_NAME, value=value)
         elif by == "css":
-            element = browser.find_element_by_css_selector(value)
+            element = browser.find_element(by=By.CSS_SELECTOR, value=value)
         elif by == "link_text":
-            element = browser.find_element_by_link_text(value)
+            element = browser.find_element(by=By.LINK_TEXT, value=value)
         else:
             self.logger.error("无对应方法，请检查")
         return element
